@@ -19,14 +19,14 @@ Usage::
     job_complete_waiter: JobCompleteWaiter = client.get_waiter("job_complete")
     ```
 """
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("JobCompleteWaiter",)
 
 
-class JobCompleteWaiter(Boto3Waiter):
+class JobCompleteWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/#jobcompletewaiter)
